VKScope enum

token permissions

Inheritance
Available extensions

Values

friends → const VKScope
photos → const VKScope
audio → const VKScope
video → const VKScope
stories → const VKScope
pages → const VKScope
status → const VKScope
notes → const VKScope
messages → const VKScope
wall → const VKScope
ads → const VKScope
offline → const VKScope
docs → const VKScope
groups → const VKScope
notifications → const VKScope
stats → const VKScope
email → const VKScope
market → const VKScope

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on VKScope, provided by the VKScopeExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VKScope>
A constant List of the values in this enum, in order of their declaration.